@@ -25,10 +25,14 @@ class Command(BaseCommand):
             raise CommandError("Usage is import_tumblr %s" % self.args)
         try:
             response = urlopen(json_url)
-            if response.code != 200:
-                raise IOError
-        except IOError:
-            raise CommandError("Invalid Tumblr user")
+            if response.code == 404:
+                raise CommandError("Invalid Tumblr user")
+            elif response.code == 503:
+                raise CommandError("Tumblr API currently unavailable")
+            elif response.code != 200:
+                raise IOError("HTTP status %s" % response.code)
+        except IOError, e:
+            raise CommandError("Error communicating with Tumblr API (%s)" % e)
         if mezzanine_user is not None:
             try:
                 mezzanine_user = User.objects.get(username=mezzanine_user)
@@ -36,8 +40,7 @@ class Command(BaseCommand):
                 raise CommandError("Invalid Mezzanine user")
 
         from mezzanine.blog.models import BlogPost
-        from mezzanine.core.models import Keyword
-        from mezzanine.settings import CONTENT_STATUS_PUBLISHED
+        from mezzanine.core.models import Keyword, CONTENT_STATUS_PUBLISHED
         site = Site.objects.get_current()
         start = "var tumblr_api_read ="
         date_format = "%a, %d %b %Y %H:%M:%S"
