@@ -3,7 +3,6 @@ from calendar import month_name
 from datetime import datetime, timedelta
 
 from django.contrib.auth.models import User
-from django.db.models import Count
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template import RequestContext
@@ -11,13 +10,10 @@ from django.template.loader import select_template
 
 from mezzanine.blog.forms import CommentForm
 from mezzanine.blog.models import BlogPost, BlogCategory
+from mezzanine.conf import settings
 from mezzanine.core.models import Keyword
 from mezzanine.pages.models import ContentPage
 from mezzanine.utils import paginate
-from mezzanine import settings as blog_settings
-
-
-use_disqus = bool(blog_settings.COMMENTS_DISQUS_SHORTNAME)
 
 
 def blog_page():
@@ -25,7 +21,7 @@ def blog_page():
     Return the Blog page from the pages app.
     """
     try:
-        return ContentPage.objects.get(slug=blog_settings.BLOG_SLUG)
+        return ContentPage.objects.get(slug=settings.BLOG_SLUG)
     except ContentPage.DoesNotExist:
         return None
 
@@ -34,8 +30,8 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
     """
     Display a list of blog posts.
     """
-    blog_posts = BlogPost.objects.published(for_user=request.user).annotate(
-        num_comments=Count("comments"))
+    settings.use_editable()
+    blog_posts = BlogPost.objects.published(for_user=request.user)
     if tag is not None:
         tag = get_object_or_404(Keyword, slug=tag)
         blog_posts = blog_posts.filter(keywords=tag)
@@ -52,10 +48,11 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
         user = get_object_or_404(User, username=username)
         blog_posts = blog_posts.filter(user=user)
     blog_posts = paginate(blog_posts, request.GET.get("page", 1),
-        blog_settings.BLOG_POST_PER_PAGE,
-        blog_settings.BLOG_POST_MAX_PAGING_LINKS)
-    context = {"blog_posts": blog_posts, "year": year, "month": month, "tag": 
-        tag, "category": category, "user": user, "use_disqus": use_disqus, 
+        settings.BLOG_POST_PER_PAGE,
+        settings.BLOG_POST_MAX_PAGING_LINKS)
+    context = {"blog_posts": blog_posts, "year": year, "month": month, 
+        "tag": tag, "category": category, "user": user, 
+        "use_disqus": bool(settings.COMMENTS_DISQUS_SHORTNAME), 
         "blog_page": blog_page()}
     return render_to_response(template, context, RequestContext(request))
 
@@ -71,8 +68,8 @@ def blog_post_detail(request, slug, template="blog/blog_post_detail.html"):
     commenter_cookie_fields = ("name", "email", "website")
     initial_comment_data = dict([(f, request.COOKIES.get(
         commenter_cookie_prefix + f, "")) for f in commenter_cookie_fields])
-    blog_post = get_object_or_404(
-        BlogPost.objects.published(for_user=request.user), slug=slug)
+    blog_posts = BlogPost.objects.published(for_user=request.user)
+    blog_post = get_object_or_404(blog_posts, slug=slug)
     posted_comment_form = CommentForm(request.POST or None,
         initial=initial_comment_data)
     unposted_comment_form = CommentForm(initial=initial_comment_data)
@@ -93,8 +90,10 @@ def blog_post_detail(request, slug, template="blog/blog_post_detail.html"):
             response.set_cookie(commenter_cookie_prefix + field,
                 request.POST.get(field, ""), expires=expires)
         return response
+    settings.use_editable()
     context = {"blog_post": blog_post, "blog_page": blog_page(), 
-        "use_disqus": use_disqus, "posted_comment_form": posted_comment_form, 
+        "use_disqus": bool(settings.COMMENTS_DISQUS_SHORTNAME), 
+        "posted_comment_form": posted_comment_form, 
         "unposted_comment_form": unposted_comment_form}
     t = select_template(["blog/%s.html" % slug, template])
     return HttpResponse(t.render(RequestContext(request, context)))
