@@ -1,12 +1,13 @@
 
-from django.conf import settings
-from django.db.models import AutoField
 from django.contrib import admin
+from django.db.models import AutoField
+from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 
-from mezzanine.utils import content_media_urls
+from mezzanine.conf import settings
 from mezzanine.core.forms import DynamicInlineAdminForm
 from mezzanine.core.models import Orderable
+from mezzanine.utils import content_media_urls, admin_url
 
 
 # Build the list of admin JS file for ``Displayable`` models.
@@ -18,8 +19,8 @@ from django import VERSION
 if not (VERSION[0] <= 1 and VERSION[1] <= 1):
     displayable_js.append("js/collapse_backport.js")
 displayable_js = content_media_urls(*displayable_js)
-displayable_js.insert(0, "%stinymce/jscripts/tiny_mce/tiny_mce.js" % 
-    settings.ADMIN_MEDIA_PREFIX)
+displayable_js.insert(0, "%s/jscripts/tiny_mce/tiny_mce.js" % 
+                                                    settings.TINYMCE_URL)
 
 
 class DisplayableAdmin(admin.ModelAdmin):
@@ -105,3 +106,55 @@ class OwnableAdmin(admin.ModelAdmin):
         if request.user.is_superuser:
             return qs
         return qs.filter(user__id=request.user.id)
+
+
+class SingletonAdmin(admin.ModelAdmin):
+    """
+    Admin class for models that should only contain a single instance in the 
+    database. Redirect all views to the change view when the instance exists, 
+    and to the add view when it doesn't.
+    """
+
+    def add_view(self, *args, **kwargs):
+        """
+        Redirect to the change view if the singlton instance exists.
+        """
+        try:
+            singleton = self.model.objects.get()
+        except (self.model.DoesNotExist, self.model.MultipleObjectsReturned):
+            return super(SingletonAdmin, self).add_view(*args, **kwargs)
+        else:
+            change_url = admin_url(self.model, "change", singleton.id)
+            return HttpResponseRedirect(change_url)
+
+    def changelist_view(self, *args, **kwargs):
+        """
+        Redirect to the add view if no records exist or the change view if 
+        the singlton instance exists.
+        """
+        try:
+            singleton = self.model.objects.get()
+        except self.model.MultipleObjectsReturned:
+            return super(SingletonAdmin, self).changelist_view(*args, **kwargs)
+        except self.model.DoesNotExist:
+            add_url = admin_url(model, "add")
+            return HttpResponseRedirect(add_url)
+        else:
+            change_url = admin_url(self.model, "change", singleton.id)
+            return HttpResponseRedirect(change_url)
+
+    def change_view(self, request, object_id, extra_context=None):
+        """
+        If only the singleton instance exists, pass True for ``singleton`` 
+        into the template which will use CSS to hide relevant buttons.
+        """
+        if extra_context is None:
+            extra_context = {}
+        try:
+            self.model.objects.get()
+        except (self.model.DoesNotExist, self.model.MultipleObjectsReturned):
+            pass
+        else:
+            extra_context["singleton"] = True
+        return super(SingletonAdmin, self).change_view(request, object_id, 
+                                                        extra_context)
