@@ -6,9 +6,9 @@ from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.conf import settings
 from mezzanine.core.forms import get_edit_form
 from mezzanine.core.models import Keyword, Displayable
-from mezzanine.settings import SEARCH_MAX_PAGING_LINKS, SEARCH_PER_PAGE
 from mezzanine.utils import is_editable, paginate
 
 
@@ -31,18 +31,23 @@ def search(request, template="search_results.html"):
     """
     Display search results.
     """
+    settings.use_editable()
     query = request.GET.get("q", "")
     results = Displayable.objects.search(query)
-    results = paginate(results, request.GET.get("page", 1), SEARCH_PER_PAGE,
-        SEARCH_MAX_PAGING_LINKS)
+    results = paginate(results, request.GET.get("page", 1), 
+        settings.SEARCH_PER_PAGE, settings.SEARCH_MAX_PAGING_LINKS)
     context = {"query": query, "results": results}
     return render_to_response(template, context, RequestContext(request))
 
 
 def edit(request):
+    """
+    Process the inline editing form.
+    """
     model = get_model(request.POST["app"], request.POST["model"])
     obj = model.objects.get(id=request.POST["id"])
-    form = get_edit_form(obj, request.POST["attr"], data=request.POST)
+    form = get_edit_form(obj, request.POST["fields"], data=request.POST,
+                        files=request.FILES)
     if not is_editable(obj, request):
         response = _("Permission denied")
     elif form.is_valid():
