@@ -1,10 +1,12 @@
 
-from django.core.urlresolvers import resolve
+from django.contrib.admin.util import quote
+from django.core.urlresolvers import resolve, reverse
 from django.db import models
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.core.models import Displayable, Orderable, Content
+from mezzanine.utils import admin_url
 
 
 class Page(Orderable, Displayable):
@@ -34,6 +36,9 @@ class Page(Orderable, Displayable):
     def get_absolute_url(self):
         return ("page", (), {"slug": self.get_slug()})
 
+    def get_admin_url(self):
+        return admin_url(self, "change", self.id)
+
     def save(self, *args, **kwargs):
         """
         Create the titles field using the titles up the parent chain and set
@@ -77,6 +82,5 @@ class ContentPage(Page, Content):
     """
 
     class Meta:
-        verbose_name = _("Content")
+        verbose_name = _("Content page")
         verbose_name_plural = _("Content pages")
-
