@@ -41,6 +41,7 @@ INSTALLED_APPS = (
     "django.contrib.redirects",
     "django.contrib.sessions",
     "django.contrib.sites",
+    "mezzanine.conf",
     "mezzanine.core",
     "mezzanine.blog",
     "mezzanine.forms",
@@ -54,6 +55,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     "django.core.context_processors.i18n",
     "django.core.context_processors.media",
     "django.core.context_processors.request",
+    "mezzanine.conf.context_processors.settings",
 )
 
 MIDDLEWARE_CLASSES = (
@@ -164,15 +166,29 @@ if command == "runserver" and PACKAGE_NAME_GRAPPELLI in INSTALLED_APPS:
         addr = "127.0.0.1"
     ADMIN_MEDIA_PREFIX = "http://%s:%s%s" % (addr, port, ADMIN_MEDIA_PREFIX)
 
-db_engine = DATABASE_ENGINE.split(".")[-1]
-if db_engine == "sqlite3" and "/" not in DATABASE_NAME:
-    # If the sqlite DB name doesn't contain a path, assume it's in the 
-    # project directory and add the path to it.
-    DATABASE_NAME = os.path.join(project_path, DATABASE_NAME)
-elif db_engine == "mysql":
-    # Required MySQL collation for tests.
-    TEST_DATABASE_COLLATION = "utf8_general_ci"
-elif db_engine.startswith("postgresql") and not globals().get("TIME_ZONE", 1):
-    # Specifying a blank time zone to fall back to the system's time zone
-    # will break table creation in Postgres so remove it.
-    del TIME_ZONE
+multi_db = (not globals().get("DATABASE_ENGINE")) and "DATABASES" in globals()
+if multi_db:
+    dbs = DATABASES
+else:
+    dbs = {None: {"ENGINE": DATABASE_ENGINE, "NAME": DATABASE_NAME}}
+for key, db in dbs.items():
+    engine = db["ENGINE"].split(".")[-1]
+    if engine == "sqlite3" and os.sep not in db["NAME"]:
+        # If the sqlite DB name doesn't contain a path, assume it's in the 
+        # project directory and add the path to it.
+        name = os.path.join(project_path, db["NAME"])
+        if multi_db:
+            DATABASES[key]["NAME"] = name
+        else:
+            DATABASE_NAME = name
+    elif engine == "mysql":
+        # Required MySQL collation for tests.
+        collation = "utf8_general_ci"
+        if multi_db:
+            DATABASES[key]["TEST_COLLATION"] = collation
+        else:
+            TEST_DATABASE_COLLATION = collation
+    elif engine.startswith("postgresql") and not globals().get("TIME_ZONE", 1):
+        # Specifying a blank time zone to fall back to the system's time zone
+        # will break table creation in Postgres so remove it.
+        del TIME_ZONE
