@@ -1,8 +1,9 @@
 
-from django.conf import settings
 from django.conf.urls.defaults import *
 from django.contrib import admin
 
+from mezzanine.conf import settings
+
 
 admin.autodiscover()
 
